@@ -191,6 +191,9 @@ void DFArcFrame::PrepareGUI()
   mV107->SetValue(mConfig->mV107Value);
 
   // Default logo (currently all black with a question mark)
+  /* TRANSLATORS: please make this SHORT, possibly rephrasing as "<
+     Choose!". This is included in the 160x120px logo box in the main
+     window and it doesn't word-wrap. */
   mDefaultLogoBitmap = CreateTextLogo(_("< Pick a D-Mod"));
   mLogoButton->SetBitmap(mDefaultLogoBitmap);
 }
